==> gnome-system-tools-0.23.0.tar.bz2: gnome-system-tools-0.23.0/interfaces/network.glade.h <==
/*
 * Archivo de cadenas traducibles generado por Glade.
 * Añada este archivo a su POTFILES.in de su proyecto.
 * NO lo compile como parte de su aplicación.
 */

gchar *s = N_("Networking Settings");
gchar *s = N_("How this computer is identified.");
gchar *s = N_("<span weight=\"bold\">Host settings</span>");
gchar *s = N_("_Host name:");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Windows networking</span>");
gchar *s = N_("_Enable Windows networking");
gchar *s = N_("_Description:");
gchar *s = N_("Domain / _Workgroup:");
gchar *s = N_("WI_NS server:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("General");
gchar *s = N_("How other computers are accessed.");
gchar *s = N_("_Add...");
gchar *s = N_("_Delete...");
gchar *s = N_("_Configure...");
gchar *s = N_("Default Gateway Device:");
gchar *s = N_("Use \"Auto\" if unsure.");
gchar *s = N_("Auto");
gchar *s = N_("Connections");
gchar *s = N_("How the names of other\n"
              "computers are found.");
gchar *s = N_("_Domain name:");
gchar *s = N_("*");
gchar *s = N_("DNS _Servers:");
gchar *s = N_("Sea_rch Domains:");
gchar *s = N_("DNS");
gchar *s = N_("Aliases of other computers.");
gchar *s = N_("_IP address:");
gchar *s = N_("*");
gchar *s = N_("A_liases:");
gchar *s = N_("_Add");
gchar *s = N_("_Delete");
gchar *s = N_("Hosts");
gchar *s = N_("New Connection Type");
gchar *s = N_("Select which type of connection you would like to add.");
gchar *s = N_("_Modem (PPP)");
gchar *s = N_("_Ethernet");
gchar *s = N_("_Wavelan");
gchar *s = N_("_Parallel Line");
gchar *s = N_("_IR LAN");
gchar *s = N_("Connection Settings");
gchar *s = N_("Use the comment to identify the interface in the future. Activation management lets you set who will activate connections, and when.");
gchar *s = N_("<span weight=\"bold\">Connection</span>");
gchar *s = N_("Device:");
gchar *s = N_("_Comment:");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Activation</span>");
gchar *s = N_("Allow activation control for all _users");
gchar *s = N_("Activate when the computer _starts");
gchar *s = N_("General");
gchar *s = N_("How the IP address for this connection is determined.");
gchar *s = N_("_Configuration:");
gchar *s = N_("Manual");
gchar *s = N_("DHCP");
gchar *s = N_("BOOTP");
gchar *s = N_("_Gateway address:");
gchar *s = N_("_Subnet mask:");
gchar *s = N_("_IP address:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("_Update DNS when this connection becomes active");
gchar *s = N_("IP Settings");
gchar *s = N_("Wireless networking settings.");
gchar *s = N_("_Ad-Hoc mode");
gchar *s = N_("_Session ID:");
gchar *s = N_("_Frequency (GHz):");
gchar *s = N_("*");
gchar *s = N_("2.422");
gchar *s = N_("*");
gchar *s = N_("_Channel:");
gchar *s = N_("Ad-Hoc Settings");
gchar *s = N_("WaveLAN");
gchar *s = N_("How to dial up to the internet.");
gchar *s = N_("<span weight=\"bold\">Account data</span>");
gchar *s = N_("Phone _number:");
gchar *s = N_("_User name:");
gchar *s = N_("_Password:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Options</span>");
gchar *s = N_("_Modem port:");
gchar *s = N_("*");
gchar *s = N_("_Retry if the connection drops or fails to start");
gchar *s = N_("_Dial type:");
gchar *s = N_("Tones");
gchar *s = N_("Pulses");
gchar *s = N_("_Modem volume:");
gchar *s = N_("Account");
gchar *s = N_("Advanced PPP connection tuning.");
gchar *s = N_("<span weight=\"bold\">PPP options</span>");
gchar *s = N_("Pppd _options:");
gchar *s = N_("*");
gchar *s = N_("_Start PPP as soon as modem connects");
gchar *s = N_("Set modem as default _route to internet");
gchar *s = N_("<span weight=\"bold\">DNS Servers</span>");
gchar *s = N_("Set _DNS servers manually");
gchar *s = N_("_Primary:");
gchar *s = N_("*");
gchar *s = N_("Se_condary:");
gchar *s = N_("*");
gchar *s = N_("Advanced");
gchar *s = N_("How the IP addresses for this connection \n"
              "are determined.");
gchar *s = N_("_Local IP:");
gchar *s = N_("_Remote IP:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("_Use remote IP as default gateway");
gchar *s = N_("IP Settings");
gchar *s = N_("Add New Internet Connection");
gchar *s = N_("Create a new Internet Connection ");
gchar *s = N_("Welcome to the Internet Connection druid. \n"
              "\n"
              "This druid will help you configure a new \n"
              "Internet account. \n"
              "\n"
              "Before you begin, you must have a modem and\n"
              "an Internet Service Provider (ISP). Please ask your \n"
              "ISP for any pertinent information about your connection.\n"
              "\n"
              "Click the \"Next\" button to begin.");
gchar *s = N_("1. ISP phone number");
gchar *s = N_("First, please enter the phone number you use to connect to the internet. This number is provided by your ISP. ");
gchar *s = N_("Phone number:");
gchar *s = N_("*");
gchar *s = N_("To continue configuring your account, click \"Next\". To quit, click \"Cancel\".\n"
              "");
gchar *s = N_("Warning message goes here.\n"
              "");
gchar *s = N_("2. Username and password");
gchar *s = N_("Next, please enter the user name and password which were assigned to you by your ISP.");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("Password (confirm):");
gchar *s = N_("*");
gchar *s = N_("User name:");
gchar *s = N_("Password:");
gchar *s = N_("Warning message goes here..\n"
              "");
gchar *s = N_("To continue configuring your account, click \"Next\". To quit, click \"Cancel\".\n"
              "");
gchar *s = N_("3. Account name");
gchar *s = N_("Now, please give this account a name. This name will be used to identify the account.");
gchar *s = N_("Account name:");
gchar *s = N_("*");
gchar *s = N_("To continue configuring your account, click \"Next\". To quit, click \"Cancel\".\n"
              "");
gchar *s = N_("Warning message goes here..\n"
              "");
gchar *s = N_("Finished");
gchar *s = N_("Summary of new account data\n"
              "goes here, plus indications on\n"
              "how to proceed (go back, cancel\n"
              "or finish).");
gchar *s = N_("Connection active");
gchar *s = N_("Activate when the computer starts");
gchar *s = N_("Allow activation control for all users");
gchar *s = N_("Activation");

==> gnome-system-tools-0.25.0.tar.bz2: gnome-system-tools-0.25.0/interfaces/network.glade.h <==
/*
 * Archivo de cadenas traducibles generado por Glade.
 * Añada este archivo a su POTFILES.in de su proyecto.
 * NO lo compile como parte de su aplicación.
 */

gchar *s = N_("Networking Settings");
gchar *s = N_("How this computer is identified.");
gchar *s = N_("<span weight=\"bold\">Host Settings</span>");
gchar *s = N_("_Host name:");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Windows Networking</span>");
gchar *s = N_("_Description:");
gchar *s = N_("Domain / _Workgroup:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("WI_NS server:");
gchar *s = N_("_Enable Windows networking");
gchar *s = N_("General");
gchar *s = N_("How other computers are accessed.");
gchar *s = N_("_Add...");
gchar *s = N_("_Configure");
gchar *s = N_("Default gateway device:");
gchar *s = N_("Use \"Auto\" if unsure.");
gchar *s = N_("Auto");
gchar *s = N_("Connections");
gchar *s = N_("How the names of other\n"
              "computers are found.");
gchar *s = N_("_Domain name:");
gchar *s = N_("*");
gchar *s = N_("DNS _Servers:");
gchar *s = N_("Sea_rch Domains:");
gchar *s = N_("DNS");
gchar *s = N_("Aliases of other computers.");
gchar *s = N_("*");
gchar *s = N_("A_liases:");
gchar *s = N_("_Delete");
gchar *s = N_("_IP address:");
gchar *s = N_("Hosts");
gchar *s = N_("New Connection Type");
gchar *s = N_("_Modem (PPP)");
gchar *s = N_("_Ethernet");
gchar *s = N_("_Wavelan");
gchar *s = N_("_Parallel Line");
gchar *s = N_("_IR LAN");
gchar *s = N_("Select which type of connection\n"
              "you would like to add.");
gchar *s = N_("Connection Settings");
gchar *s = N_("Use the comment to identify the interface in the future. Activation management lets you set who will activate connections, and when.");
gchar *s = N_("<span weight=\"bold\">Connection</span>");
gchar *s = N_("Device:");
gchar *s = N_("_Comment:");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Activation</span>");
gchar *s = N_("Allow activation control for all _users");
gchar *s = N_("Activate when the computer _starts");
gchar *s = N_("General");
gchar *s = N_("How the IP address for this connection is determined.");
gchar *s = N_("_Configuration:");
gchar *s = N_("Manual");
gchar *s = N_("DHCP");
gchar *s = N_("BOOTP");
gchar *s = N_("_Gateway address:");
gchar *s = N_("_Subnet mask:");
gchar *s = N_("_IP address:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("_Update DNS when this connection becomes active");
gchar *s = N_("IP Settings");
gchar *s = N_("How the IP addresses for this connection \n"
              "are determined.");
gchar *s = N_("_Local IP:");
gchar *s = N_("_Remote IP:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("_Use remote IP as default gateway");
gchar *s = N_("IP Settings");
gchar *s = N_("Wireless networking settings.");
gchar *s = N_("_Ad-Hoc mode");
gchar *s = N_("_Session ID:");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Ad-Hoc Settings</span>");
gchar *s = N_("_Channel:");
gchar *s = N_("_Frequency (GHz):");
gchar *s = N_("2.422");
gchar *s = N_("*");
gchar *s = N_("WaveLAN");
gchar *s = N_("How to dial up to the internet.");
gchar *s = N_("<span weight=\"bold\">Account Data</span>");
gchar *s = N_("Phone _number:");
gchar *s = N_("_User name:");
gchar *s = N_("_Password:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("_Modem port:");
gchar *s = N_("_Dial type:");
gchar *s = N_("_Modem volume:");
gchar *s = N_("<span weight=\"bold\">Access Settings</span>");
gchar *s = N_("Tones");
gchar *s = N_("Pulses");
gchar *s = N_("_Retry if the connection drops or fails to start");
gchar *s = N_("_Autodetect");
gchar *s = N_("*");
gchar *s = N_("/dev/modem");
gchar *s = N_("/dev/ttyS0");
gchar *s = N_("/dev/ttyS1");
gchar *s = N_("/dev/ttyS2");
gchar *s = N_("/dev/ttyS3");
gchar *s = N_("Account");
gchar *s = N_("Advanced PPP connection tuning.");
gchar *s = N_("<span weight=\"bold\">PPP Settings</span>");
gchar *s = N_("PPPD _options:");
gchar *s = N_("*");
gchar *s = N_("_Start PPP as soon as modem connects");
gchar *s = N_("Set modem as default _route to internet");
gchar *s = N_("<span weight=\"bold\">DNS Servers</span>");
gchar *s = N_("_Primary:");
gchar *s = N_("*");
gchar *s = N_("Se_condary:");
gchar *s = N_("*");
gchar *s = N_("Set _DNS servers manually");
gchar *s = N_("Advanced");
gchar *s = N_("Add New Internet Connection");
gchar *s = N_("Create a new Internet Connection ");
gchar *s = N_("Welcome to the Internet Connection druid. \n"
              "\n"
              "This druid will help you configure a new \n"
              "Internet account. \n"
              "\n"
              "Before you begin, you must have a modem and\n"
              "an Internet Service Provider (ISP). Please ask your \n"
              "ISP for any pertinent information about your connection.\n"
              "\n"
              "Click the \"Next\" button to begin.");
gchar *s = N_("1. ISP phone number");
gchar *s = N_("First, please enter the phone number you use to connect to the internet. This number is provided by your ISP. ");
gchar *s = N_("Phone number:");
gchar *s = N_("*");
gchar *s = N_("To continue configuring your account, click \"Next\". To quit, click \"Cancel\".\n"
              "");
gchar *s = N_("Warning message goes here.\n"
              "");
gchar *s = N_("2. Username and password");
gchar *s = N_("Next, please enter the user name and password which were assigned to you by your ISP.");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("Password (confirm):");
gchar *s = N_("*");
gchar *s = N_("User name:");
gchar *s = N_("Password:");
gchar *s = N_("Warning message goes here..\n"
              "");
gchar *s = N_("To continue configuring your account, click \"Next\". To quit, click \"Cancel\".\n"
              "");
gchar *s = N_("3. Account name");
gchar *s = N_("Now, please give this account a name. This name will be used to identify the account.");
gchar *s = N_("Account name:");
gchar *s = N_("*");
gchar *s = N_("To continue configuring your account, click \"Next\". To quit, click \"Cancel\".\n"
              "");
gchar *s = N_("Warning message goes here..\n"
              "");
gchar *s = N_("Finished");
gchar *s = N_("Summary of new account data\n"
              "goes here, plus indications on\n"
              "how to proceed (go back, cancel\n"
              "or finish).");
gchar *s = N_("Connection active");
gchar *s = N_("Activate when the computer starts");
gchar *s = N_("Allow activation control for all users");
gchar *s = N_("Activation");
gchar *s = N_("New network connection");
gchar *s = N_("Create a new network connection");
gchar *s = N_("Welcome to the Network Connection druid. \n"
              "\n"
              "This druid will help you configure a new \n"
              "network connection. \n"
              "\n"
              "Click the \"Next\" button to begin.");
gchar *s = N_("Connection type");
gchar *s = N_("Please, select which type of connection you would like to add.");
gchar *s = N_("_Modem (PPP)");
gchar *s = N_("_Ethernet");
gchar *s = N_("_Wavelan");
gchar *s = N_("_Parallel Line");
gchar *s = N_("_IR LAN");
gchar *s = N_("To continue configuring your network connection, click \"Next\". To quit, click \"Cancel\".");
gchar *s = N_("Address configuration (Step 1 of 2)");
gchar *s = N_("Now, please enter the address that \n"
              "this network device will have.");
gchar *s = N_("_Gateway address:");
gchar *s = N_("_Subnet mask:");
gchar *s = N_("_IP address:");
gchar *s = N_("_Configuration:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("Manual");
gchar *s = N_("DHCP");
gchar *s = N_("BOOTP");
gchar *s = N_("To continue configuring your network connection, click \"Next\". To quit, click \"Cancel\".");
gchar *s = N_("Address configuration (Step 1 of 2)");
gchar *s = N_("Now, please enter the address that this network device will have,\n"
              "and the remote address to which it will be connected.");
gchar *s = N_("_Local IP address:");
gchar *s = N_("_Remote IP address:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("_Use remote IP as default gateway");
gchar *s = N_("To continue configuring your network connection, click \"Next\". To quit, click \"Cancel\".");
gchar *s = N_("ISP phone number (Step 1 of 3)");
gchar *s = N_("Please enter the phone number you use to connect to the internet. This number is provided by your ISP. ");
gchar *s = N_("Phone number:");
gchar *s = N_("*");
gchar *s = N_("To continue configuring your network connection, click \"Next\". To quit, click \"Cancel\".");
gchar *s = N_("Username and password (Step 2 of 3)");
gchar *s = N_("Next, please enter the user name and password which were assigned to you by your ISP.");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("Password (confirm):");
gchar *s = N_("*");
gchar *s = N_("User name:");
gchar *s = N_("Password:");
gchar *s = N_("To continue configuring your network connection, click \"Next\". To quit, click \"Cancel\".");
gchar *s = N_("Connection name (Step 3 of 3)");
gchar *s = N_("Now, please give this connection a name.");
gchar *s = N_("Connection name:");
gchar *s = N_("*");
gchar *s = N_("To continue configuring your network connection, click \"Next\". To quit, click \"Cancel\".");
gchar *s = N_("Finished");
gchar *s = N_("You are about to create a new network connection.\n"
              "\n"
              "Please click \"Apply\" to save your changes.");
